@@ -1,6 +1,5 @@
 use {
     crate::*,
-    anyhow::{bail, Result},
     flate2::bufread::GzDecoder,
     std::{
         fs::File,
@@ -11,16 +10,16 @@ use {
     termimad::{
         crossterm::{
             cursor,
-            execute,
             style::{style, Color, Print, PrintStyledContent, Stylize},
             terminal::{Clear, ClearType},
             queue,
+            tty::IsTty,
         },
         ProgressBar,
     },
 };
 
-pub fn get_file_first_date(path: &Path) -> Result<Option<Date>> {
+pub fn get_file_first_date(path: &Path) -> Result<Option<Date>, RhitError> {
     debug!("reading date in file {:?}", &path);
     let file = File::open(path)?;
     if path.extension().and_then(|e| e.to_str()) == Some("gz") {
@@ -30,7 +29,7 @@ pub fn get_file_first_date(path: &Path) -> Result<Option<Date>> {
         read_first_date(file)
     }
 }
-fn read_first_date<R: Read>(file: R) -> Result<Option<Date>> {
+fn read_first_date<R: Read>(file: R) -> Result<Option<Date>, RhitError> {
     let mut reader = BufReader::new(file);
     let mut line = String::new();
     // a log file may contain non log lines, for example when
@@ -48,7 +47,7 @@ fn read_first_date<R: Read>(file: R) -> Result<Option<Date>> {
         }
         match LogLine::from_str(&line) {
             Ok(l) => {
-                return Ok(Some(l.date));
+                return Ok(Some(l.date()));
             }
             _ => {
                 debug!("skipping line {:?}", &line);
@@ -71,37 +70,34 @@ where
     silent: bool,
 }
 
-pub trait LineConsumer {
-    fn start_eating(
-        &mut self,
-        first_date: Date,
-    );
-    fn eat_line(
-        &mut self,
-        log_line: LogLine,
-        raw_line: &str,
-        filtered_out: bool,
-    );
-}
 
 impl<'c, C: LineConsumer> FileReader<'c, C> {
     pub fn new(
         paths: &[PathBuf],
         args: &args::Args,
         consumer: &'c mut C,
-    ) -> Result<Self> {
+    ) -> Result<Self, RhitError> {
         let check_names = !args.no_name_check;
         let roots = paths.to_vec().into_boxed_slice();
         let ff = FileFinder::new(&roots, check_names);
         let mut dated_files = time!(ff.dated_files())?;
         if dated_files.is_empty() {
-            bail!("no log file found");
+            return Err(RhitError::NoLogFileFound);
         }
         let first_date = dated_files[0].0;
         let last_date = dated_files[dated_files.len()-1].0; // last first date
         let filterer = Filterer::new(args, first_date, last_date)?;
         let paths: Vec<PathBuf> = dated_files.drain(..).map(|df| df.1).collect();
         let stop_on_error = check_names;
+        let silent = if args.silent_load {
+            true
+        } else if args.output != Output::Tables && std::io::stdout().is_tty() {
+            // if we dump many lines to the terminal, the progress bar is
+            // at best flown away
+            true
+        } else {
+            false
+        };
         consumer.start_eating(first_date);
         Ok(Self {
             roots,
@@ -109,7 +105,7 @@ impl<'c, C: LineConsumer> FileReader<'c, C> {
             consumer,
             paths,
             stop_on_error,
-            silent: args.silent_load,
+            silent,
         })
     }
     pub fn filterer(self) -> Filterer {
@@ -117,7 +113,7 @@ impl<'c, C: LineConsumer> FileReader<'c, C> {
     }
     pub fn read_all_files(
         &mut self,
-    ) -> Result<()> {
+    ) -> Result<(), RhitError> {
         let total =  self.paths.len();
         let mut done = 0;
         if !self.silent {
@@ -137,7 +133,10 @@ impl<'c, C: LineConsumer> FileReader<'c, C> {
                 print_progress(done, total)?;
             }
         }
-        execute!(io::stderr(), Clear(ClearType::CurrentLine))?;
+        if !self.silent {
+            clear_progress()?;
+        }
+        self.consumer.end_eating();
         if !self.silent {
             // if we're here, total, which is the count of log files, is at least 1
             let roots_string = if self.roots.len() == 1 {
@@ -154,8 +153,8 @@ impl<'c, C: LineConsumer> FileReader<'c, C> {
         }
         Ok(())
     }
-    fn read_file_lines(&mut self, path: &Path) -> Result<()> {
-        let file = File::open(&path)?;
+    fn read_file_lines(&mut self, path: &Path) -> Result<(), RhitError> {
+        let file = File::open(path)?;
         if path.extension().and_then(|e| e.to_str()) == Some("gz") {
             let file = BufReader::new(file);
             self.read_lines(GzDecoder::new(file), path)
@@ -163,7 +162,7 @@ impl<'c, C: LineConsumer> FileReader<'c, C> {
             self.read_lines(file, path)
         }
     }
-    fn read_lines<R: Read>(&mut self, file: R, path: &Path) -> Result<()> {
+    fn read_lines<R: Read>(&mut self, file: R, path: &Path) -> Result<(), RhitError> {
         debug!("reading file {:?}", path);
         let mut reader = BufReader::new(file);
         let mut line = String::new();
@@ -201,7 +200,7 @@ impl<'c, C: LineConsumer> FileReader<'c, C> {
     }
 }
 
-fn print_progress(done: usize, total: usize) -> Result<()> {
+fn print_progress(done: usize, total: usize) -> Result<(), RhitError> {
     let width = 40;
     let p = ProgressBar::new(done as f32 / (total as f32), width);
     let s = format!("{:width$}", p, width=width);
@@ -214,3 +213,12 @@ fn print_progress(done: usize, total: usize) -> Result<()> {
     stderr.flush()?;
     Ok(())
 }
+///
+fn clear_progress() -> Result<(), RhitError> {
+    let mut stderr = io::stderr();
+    queue!(stderr, cursor::SavePosition)?;
+    queue!(stderr, Clear(ClearType::CurrentLine))?;
+    queue!(stderr, cursor::RestorePosition)?;
+    stderr.flush()?;
+    Ok(())
+}
