@@ -1,8 +1,7 @@
 use {
     crate::*,
-    anyhow::*,
     std::{
-        path::Path,
+        path::PathBuf,
     },
 };
 
@@ -11,8 +10,8 @@ use {
 struct BaseContent {
     lines: Vec<LogLine>,
     bar_idx: usize,
-    unfiltered_histogram: Histogram,
-    filtered_histogram: Histogram,
+    unfiltered_histogram: DateHistogram,
+    filtered_histogram: DateHistogram,
 }
 
 impl LineConsumer for BaseContent {
@@ -20,8 +19,8 @@ impl LineConsumer for BaseContent {
         &mut self,
         first_date: Date,
     ) {
-        self.unfiltered_histogram.bars.push(Bar::new(first_date));
-        self.filtered_histogram.bars.push(Bar::new(first_date));
+        self.unfiltered_histogram.bars.push(DateBar::new(first_date));
+        self.filtered_histogram.bars.push(DateBar::new(first_date));
     }
     fn eat_line(
         &mut self,
@@ -33,9 +32,9 @@ impl LineConsumer for BaseContent {
         let fbars = &mut self.filtered_histogram.bars;
         // both histograms are synchronized, we create
         // bars even when there's no filtered hit
-        if log_line.date != ubars[self.bar_idx].date {
-            ubars.push(Bar::new(log_line.date));
-            fbars.push(Bar::new(log_line.date));
+        if log_line.date() != ubars[self.bar_idx].date {
+            ubars.push(DateBar::new(log_line.date()));
+            fbars.push(DateBar::new(log_line.date()));
             self.bar_idx += 1;
         }
         ubars[self.bar_idx].hits += 1;
@@ -50,22 +49,22 @@ impl LineConsumer for BaseContent {
 }
 
 pub struct LogBase {
-    pub dates: Vec<Date>, // keep this ?
+    pub dates: Vec<Date>, // all the days covering the observed period
     pub filterer: Filterer,
     pub lines: Vec<LogLine>,
-    pub filtered_histogram: Histogram,
+    pub filtered_histogram: DateHistogram,
     pub filtered_count: u64,
-    pub unfiltered_histogram: Histogram,
+    pub unfiltered_histogram: DateHistogram,
     pub unfiltered_count: u64,
 }
 
 impl LogBase {
     pub fn new(
-        path: &Path,
+        paths: &[PathBuf],
         args: &args::Args,
-    ) -> Result<Self> {
+    ) -> Result<Self, RhitError> {
         let mut base_content = BaseContent::default();
-        let mut file_reader = FileReader::new(path, args, &mut base_content)?;
+        let mut file_reader = FileReader::new(paths, args, &mut base_content)?;
         time!("reading files", file_reader.read_all_files())?;
         let filterer = file_reader.filterer();
         let BaseContent {lines, unfiltered_histogram, filtered_histogram, ..} = base_content;
@@ -76,7 +75,7 @@ impl LogBase {
             dates.push(bar.date);
         }
         if unfiltered_count == 0 {
-            bail!("no hit found in {:?}", path);
+            return Err(RhitError::NoHitInPaths(paths.to_vec()));
         }
         let filtered_count = filtered_histogram.total_hits();
         Ok(Self {
